{ pkgs, inputs, ... }:

{
  imports = [
    # Utilities
    ../../modules/nixos/nvidia-support.nix
    ../../modules/nixos/fingerprint.nix
    ../../modules/nixos/bluetooth.nix
    ../../modules/nixos/greetd.nix
    ../../modules/nixos/audio.nix

    # Apps + services
    ../../modules/nixos/nordvpn.nix
  ];

  modules.bluetooth.enable = true;
  modules.nordvpn.enable = true;
  modules.nvidia.enable = true;
  modules.audio.enable = true;
  modules.fingerprint-fix = {
    enable = true;
    calibDataFile = ./calib-data.bin;
  };

  services = {
    tlp.enable = false;
    gvfs.enable = true;
    upower.enable = true;
    power-profiles-daemon.enable = true;
    xserver.displayManager = {
      gdm.enable = true;
      startx.enable = true;
    };

    printing = {
      enable = true;
      drivers = with pkgs; [ hplipWithPlugin ];
    };

    udev.extraRules = ''
      SUBSYSTEM=="backlight", KERNEL=="intel_backlight", MODE="0666", RUN+="${pkgs.coreutils}/bin/chmod a+w /sys/class/backlight/%k/brightness"
    '';
  };

  programs = {
    adb.enable = true;
    thunar.enable = true;
    hyprland.enable = true;

    thunar.plugins = with pkgs.xfce; [
      thunar-archive-plugin
      thunar-volman
    ];

    light.enable = true;
  };
}
